Name:		lis
Version:	1.5.57
Release:	1%{?dist}
Summary:	A library for solving linear equations and eigenvalue problems
License:	BSD
URL:		http://www.ssisc.org/lis/index.en.html
Source0:	http://www.ssisc.org/lis/dl/lis-%{version}.tar.gz
# Disable use of -O3 -fomit-frame-pointer
Patch0:		lis-1.5.37-optflags.patch

BuildRequires:	autoconf
BuildRequires:	gcc-gfortran

%description
Lis, a Library of Iterative Solvers for linear systems, is a scalable parallel
library for solving systems of linear equations and standard eigenvalue
problems with real sparse matrices using iterative methods.

%package bin
Summary:	lis executables
Group:		Applications/Engineering

%description bin
This package contains binaries shipped with the lis library.

%package devel
Summary:	Development headers and library for lis
Group:		Applications/Engineering
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
Lis, a Library of Iterative Solvers for linear systems, is a scalable parallel
library for solving systems of linear equations and standard eigenvalue
problems with real sparse matrices using iterative methods.

This package contains the development headers and library.

%package doc
Summary:	Developer documentation for lis
Group:		Documentation
BuildArch:  noarch

%description doc
Lis, a Library of Iterative Solvers for linear systems, is a scalable parallel
library for solving systems of linear equations and standard eigenvalue
problems with real sparse matrices using iterative methods.

This package contains the developer documentation for lis.

%prep
%setup -q
%patch0 -p1 -b .optflags

%build
export CC=gcc
export F77=gfortran
export FC=gfortran
autoconf

mkdir -p omp
pushd omp
ln -s ../configure .
%configure --disable-static --enable-shared \
    --enable-fortran --enable-saamg --enable-omp \
    --enable-quad
make %{?_smp_mflags}
popd

%install
make -C omp install DESTDIR=%{buildroot}

# Get rid of .la file
rm %{buildroot}%{_libdir}/liblis.la

# .. and examples
rm -rf %{buildroot}%{_datadir}/examples

%check
install -p test/{testmat.mtx,defs,test.sh} omp/test/
pushd omp/test
sh test.sh
popd

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING
%{_libdir}/liblis.so.*

%files bin
%{_bindir}/esolve
%{_bindir}/lsolve
%{_bindir}/spmvtest?
%{_bindir}/spmvtest?b
%{_bindir}/hpcg_kernel
%{_bindir}/hpcg_spmvtest
%{_mandir}/man1/esolve.1.*
%{_mandir}/man1/lsolve.1.*
%{_mandir}/man1/spmvtest?.1.*
%{_mandir}/man1/spmvtest?b.1.*
%{_mandir}/man1/hpcg_kernel.1.*
%{_mandir}/man1/hpcg_spmvtest.1.*

%files devel
%{_includedir}/lis.h
%{_includedir}/lis_config.h
%{_includedir}/lisf.h
%{_libdir}/liblis.so

%files doc
%doc COPYING doc/*.pdf
%{_mandir}/man3/lis*.3.*
%{_mandir}/man3/lis*.3f.*

%changelog
* Fri Jul 10 2015 Florian Lehner <dev@der-flo.net> - 1.5.57-1
- Update to 1.5.57

* Thu Jun 25 2015 Florian Lehner <dev@der-flo.net> - 1.5.56-1
- Update to 1.5.56

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.54-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May  1 2015 Florian Lehner <dev@der-flo.net> - 1.5.54-1
- Update to 1.5.54

* Sun Apr  5 2015 Florian Lehner <dev@der-flo.net> - 1.5.53-1
- Update to 1.5.53

* Sun Mar 29 2015 Florian Lehner <dev@der-flo.net> - 1.5.52-1
- Update to 1.5.52

* Tue Feb 10 2015 Florian Lehner <dev@der-flo.net> - 1.5.50-1
- Update to 1.5.50

* Fri Jan 16 2015 Florian Lehner <dev@der-flo.net> - 1.5.47-1
- Update to 1.5.47

* Sat Dec 27 2014 Florian Lehner <dev@der-flo.net> - 1.5.43-1
- Update to 1.5.43

* Tue Dec 23 2014 Florian Lehner <dev@der-flo.net> - 1.5.41-1
- Update to 1.5.41
- Drop privileges is fixed upstream

* Mon Dec 22 2014 Florian Lehner <dev@der-flo.net> - 1.5.40-1
- Update to 1.5.40

* Sun Dec 14 2014 Florian Lehner <dev@der-flo.net> - 1.5.37-1
- Update to 1.5.37
- Update Patch after renaming configure.in to configure.ac

* Sat Dec 13 2014 Florian Lehner <dev@der-flo.net> - 1.5.36-1
- Update to 1.5.36

* Sun Dec  7 2014 Florian Lehner <dev@der-flo.net> - 1.5.33-1
- Update to 1.5.33

* Wed Dec  3 2014 Florian Lehner <dev@der-flo.net> - 1.5.31-1
- Update to 1.5.31

* Thu Nov 27 2014 Florian Lehner <dev@der-flo.net> - 1.5.24-1
- Update to 1.5.24

* Wed Nov 26 2014 Florian Lehner <dev@der-flo.net> - 1.5.23-1
- Update to 1.5.23

* Tue Nov 25 2014 Florian Lehner <dev@der-flo.net> - 1.5.22-1
- Update to 1.5.22

* Fri Nov 21 2014 Florian Lehner <dev@der-flo.net> - 1.5.19-1
- Update to 1.5.19

* Fri Nov 21 2014 Florian Lehner <dev@der-flo.net> - 1.5.18-1
- Update to 1.5.18

* Sat Nov 15 2014 Florian Lehner <dev@der-flo.net> - 1.5.13-1
- Update to 1.5.13

* Wed Nov 12 2014 Florian Lehner <dev@der-flo.net> - 1.5.11-1
- Update to 1.5.11

* Tue Nov  4 2014 Florian Lehner <dev@der-flo.net> - 1.5.4-1
- Update to 1.5.4

* Sat Nov  1 2014 Florian Lehner <dev@der-flo.net> - 1.5.2-1
- Update to 1.5.2

* Tue Oct 28 2014 Florian Lehner <dev@der-flo.net> - 1.4.67-1
- Update to 1.4.67

* Mon Oct 27 2014 Florian Lehner <dev@der-flo.net> - 1.4.66-1
- Update to 1.4.66

* Tue Oct 21 2014 Florian Lehner <dev@der-flo.net> - 1.4.64-1
- Update to 1.4.64

* Mon Oct 20 2014 Florian Lehner <dev@der-flo.net> - 1.4.63-1
- Update to 1.4.63

* Sat Oct 18 2014 Florian Lehner <dev@der-flo.net> - 1.4.62-1
- Update to 1.4.62

* Fri Sep 19 2014 Florian Lehner <dev@der-flo.net> - 1.4.61-1
- Update to 1.4.61

* Wed Sep 17 2014 Florian Lehner <dev@der-flo.net> - 1.4.60-1
- Update to 1.4.60

* Wed Sep 10 2014 Florian Lehner <dev@der-flo.net> - 1.4.59-1
- Update to 1.4.59

* Wed Aug 27 2014 Florian Lehner <dev@der-flo.net> - 1.4.58-1
- Update to 1.4.58

* Mon Aug 18 2014 Florian Lehner <dev@der-flo.net> - 1.4.57-1
- Update to 1.4.57

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.56-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Aug 12 2014 Florian Lehner <dev@der-flo.net> - 1.4.56-1
- Update to 1.4.56
- Drop group-tag
- Fix permission for AUTHORS and COPYING

* Mon Aug 11 2014 Florian Lehner <dev@der-flo.net> - 1.4.55-1
- Update to 1.4.55
- Add noarch to subpackage doc
- Remove requires from subpackage doc

* Sun Aug 10 2014 Florian Lehner <dev@der-flo.net> - 1.4.53-2
- Remove defattr at the beginning of the files-section
- Use default buildroot instead of making its own
- Remove unnecessary clean-section
- Use pushd and popd instead of cd

* Sat Aug  9 2014 Florian Lehner <dev@der-flo.net> - 1.4.53-1
- Update to 1.4.53

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Dec 15 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.4.20-1
- Update to 1.4.20.

* Mon Sep 09 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.4.13-1
- Update to 1.4.13.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.32-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 04 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3.32-1
- Update to 1.3.32.

* Mon Mar 04 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3.31-1
- Update to 1.3.31.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.115-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Sep 17 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.115-1
- Update to 1.2.115.

* Tue Aug 07 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.92-1
- Update to 1.2.92. Enabled SAMG.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.68-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 26 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.68-1
- Update to 1.2.68.

* Wed Jun 20 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.66-1
- Update to 1.2.66.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.58-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 22 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.58-1
- Update to 1.2.58.

* Tue Nov 08 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.56-1
- Update to 1.2.56.

* Wed Nov 02 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.54-1
- Update to 1.2.54.

* Sun Sep 18 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.53-3
- Include COPYING in -doc.

* Thu Sep 15 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.53-2
- Enabled quadruple precision support.

* Mon Sep 12 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.2.53-1
- First release.
